"""Models used by the static media management application."""

from django.db import models
from django.contrib import admin
from django.contrib.admin.widgets import ForeignKeyRawIdWidget


class Label(models.Model):
    
    """
    A notional label used to organise static media.
    
    This does not correspond to a physical label on the disk.
    """
    
    name = models.CharField(max_length=200)
    
    def __unicode__(self):
        """Returns the name of the label."""
        return self.name
    
    class Meta:
        ordering = ("name",)
    
    
class File(models.Model):
    
    """A static file."""
    
    title = models.CharField(max_length=200,
                             help_text="The title will be used as the default rollover text when this media is embedded in a web page.")
    
    labels = models.ManyToManyField(
        Label,
        blank = True,
        help_text = "Labels are used to help organise your media. They are not visible to users on your website.",
    )
    
    file = models.FileField(
        upload_to = "uploads/files",
        max_length = 250,
    )
    
    def get_absolute_url(self):
        """Generates the absolute URL of the image."""
        return self.file.url
    
    def __unicode__(self):
        """Returns the title of the media."""
        return self.title
    
    class Meta:
        ordering = ("title",)


class FileRefField(models.ForeignKey):
    
    """A foreign key to a File, constrained to only select image files."""
    
    def __init__(self, **kwargs):
        kwargs["to"] = File
        kwargs.setdefault("related_name", "+")
        kwargs.setdefault("on_delete", models.PROTECT)
        super(FileRefField, self).__init__(**kwargs)
        
    def formfield(self, **kwargs):
        defaults = {
            "widget": ForeignKeyRawIdWidget(self.rel, admin.site), 
        }
        return super(FileRefField, self).formfield(**defaults)


IMAGE_FILTER = {"file__iregex": ur"\.(png|gif|jpg|jpeg)$"} 
        
class ImageRefField(FileRefField):
    
    """A foreign key to a File, constrained to only select image files."""
    
    def __init__(self, **kwargs):
        kwargs["limit_choices_to"] = IMAGE_FILTER
        super(ImageRefField, self).__init__(**kwargs)
        
        
# Register custom fields with South.

try:
    from south.modelsinspector import add_introspection_rules
except ImportError:
    pass
else:
    add_introspection_rules((), ("^cms\.apps\.media\.models\.FileRefField",))
    add_introspection_rules((), ("^cms\.apps\.media\.models\.ImageRefField",))


"""Abstract base models used by the page management application."""

from django.db import models
from django.shortcuts import render

from cms import externals
from cms.models.managers import OnlineBaseManager, PublishedBaseManager, SearchMetaBaseManager, PageBaseManager


class PublishedBase(models.Model):
    
    """A model with publication controls."""
    
    objects = PublishedBaseManager()
    
    class Meta:
        abstract = True
        
        
class PublishedBaseSearchAdapter(externals.watson.SearchAdapter):
    
    """Base search adapter for PublishedBase derivatives."""
    
    def get_live_queryset(self):
        """Selects only live models."""
        return self.model.objects.all()


class OnlineBase(PublishedBase):
    
    objects = OnlineBaseManager()
    
    is_online = models.BooleanField(
        "online",
        default = True,
        help_text = (
            "Uncheck this box to remove the page from the public website. "
            "Logged-in admin users will still be able to view this page by clicking the 'view on site' button."
        ),
    )
    
    class Meta:
        abstract = True
        
        
class OnlineBaseSearchAdapter(PublishedBaseSearchAdapter):
    
    """Base search adapter for OnlineBase derivatives."""


class SearchMetaBase(OnlineBase):
    
    """Base model for models used to generate a standalone HTML page."""
    
    objects = SearchMetaBaseManager()
    
    # SEO fields.
    
    browser_title = models.CharField(
        max_length = 1000,
        blank = True,
        help_text = (
            "The heading to use in the user's web browser. "
            "Leave blank to use the page title. "
            "Search engines pay particular attention to this attribute."
        )
    )
    
    meta_keywords = models.CharField(
        "keywords",
         max_length = 1000,
         blank = True,
         help_text = (
            "A comma-separated list of keywords for this page. Use this to specify common mis-spellings "
            "or alternative versions of important words in this page."
        ),
    )

    meta_description = models.TextField(
        "description",
        blank = True,
        help_text = "A brief description of the contents of this page.",
    )
    
    sitemap_priority = models.FloatField(
        "priority",
        choices = (
            (1.0, "Very high"),
            (0.8, "High"),
            (0.5, "Medium"),
            (0.3, "Low"),
            (0.0, "Very low"),
        ),
        default = None,
        blank = True,
        null = True,
        help_text = (
            "The relative importance of this content in your site.  Search engines use this "
            "as a hint when ranking the pages within your site."
        ),
    )

    sitemap_changefreq = models.IntegerField(
        "change frequency",
        choices = (
            (1, "Always"),
            (2, "Hourly"),
            (3, "Daily"),
            (4, "Weekly"),
            (5, "Monthly"),
            (6, "Yearly"),
            (7, "Never")
        ),
        default = None,
        blank = True,
        null = True,
        help_text = (
            "How frequently you expect this content to be updated."
            "Search engines use this as a hint when scanning your site for updates."
        ),
    )
    
    robots_index = models.BooleanField(
        "allow indexing",
        default = True,
        help_text = (
            "Use this to prevent search engines from indexing this page. "
            "Disable this only if the page contains information which you do not wish "
            "to show up in search results."
        ),
    )

    robots_follow = models.BooleanField(
        "follow links",
         default = True,
         help_text = (
            "Use this to prevent search engines from following any links they find in this page. "
            "Disable this only if the page contains links to other sites that you do not wish to "
            "publicise."
        ),
    )

    robots_archive = models.BooleanField(
        "allow archiving",
        default = True,
        help_text = (
            "Use this to prevent search engines from archiving this page. "
            "Disable this only if the page is likely to change on a very regular basis. "
        ),
    )
    
    def get_context_data(self):
        """Returns the SEO context data for this page."""
        title = unicode(self)
        # Return the context.
        return {
            "meta_description": self.meta_description,
            "meta_keywords": self.meta_keywords,
            "robots_index": self.robots_index,
            "robots_archive": self.robots_archive,
            "robots_follow": self.robots_follow,
            "title": self.browser_title or title,
            "header": title,
        }
        
    def render(self, request, template, context=None, **kwargs):
        """Renders a template as a HttpResponse using the context of this page."""
        page_context = self.get_context_data()
        page_context.update(context or {})
        return render(request, template, page_context, **kwargs)
        
    class Meta:
        abstract = True


class SearchMetaBaseSearchAdapter(OnlineBaseSearchAdapter):

    """Search adapter for SearchMetaBase derivatives."""
    
    def get_description(self, obj):
        """Returns the meta description."""
        return obj.meta_description
    
    def get_live_queryset(self):
        """Selects only live models."""
        return super(OnlineBaseSearchAdapter, self).get_live_queryset().filter(
            robots_index = True,
        )
    

class PageBase(SearchMetaBase):
    
    """
    An enhanced SearchMetaBase with a sensible set of common features suitable for
    most pages.
    """
    
    objects = PageBaseManager()
    
    # Base fields.
    
    url_title = models.SlugField(
        "URL title",
    )
    
    title = models.CharField(
        max_length = 1000,
    )
    
    # Navigation fields.
    
    short_title = models.CharField(
        max_length = 200,
        blank = True,
        help_text = (
            "A shorter version of the title that will be used in site navigation. "
            "Leave blank to use the full-length title."
        ),
    )
    
    # SEO fields.
    
    def get_context_data(self):
        """Returns the SEO context data for this page."""
        context_data = super(PageBase, self).get_context_data()
        context_data.update({
            "title": self.browser_title or self.title,
            "header": self.title,
        })
        return context_data
    
    # Base model methods.
    
    def __unicode__(self):
        """
        Returns the short title of this page, falling back to the standard
        title.
        """
        return self.short_title or self.title
    
    class Meta:
        abstract = True
        
        
class PageBaseSearchAdapter(SearchMetaBaseSearchAdapter):
    
    """Search adapter for PageBase derivatives."""
    
    def get_title(self, obj):
        """Returns the title of the page."""
        return obj.title


# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'Label'
        db.create_table('media_label', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=200)),
        ))
        db.send_create_signal('media', ['Label'])

        # Adding model 'File'
        db.create_table('media_file', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=200)),
            ('file', self.gf('django.db.models.fields.files.FileField')(max_length=250)),
        ))
        db.send_create_signal('media', ['File'])

        # Adding M2M table for field labels on 'File'
        db.create_table('media_file_labels', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('file', models.ForeignKey(orm['media.file'], null=False)),
            ('label', models.ForeignKey(orm['media.label'], null=False))
        ))
        db.create_unique('media_file_labels', ['file_id', 'label_id'])

    def backwards(self, orm):
        # Deleting model 'Label'
        db.delete_table('media_label')

        # Deleting model 'File'
        db.delete_table('media_file')

        # Removing M2M table for field labels on 'File'
        db.delete_table('media_file_labels')

    models = {
        'media.file': {
            'Meta': {'ordering': "('title',)", 'object_name': 'File'},
            'file': ('django.db.models.fields.files.FileField', [], {'max_length': '250'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'labels': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['media.Label']", 'symmetrical': 'False', 'blank': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '200'})
        },
        'media.label': {
            'Meta': {'ordering': "('name',)", 'object_name': 'Label'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '200'})
        }
    }

    complete_apps = ['media']


"""Admin settings for the CMS news app."""

from django.contrib import admin

from cms.admin import PageBaseAdmin
from cms.apps.news.models import Category, Article


class CategoryAdmin(PageBaseAdmin):
    
    """Admin settings for the Category model."""
    
    fieldsets = (
        PageBaseAdmin.TITLE_FIELDS,
        ("Content", {
            "fields": ("content_primary",),
        }),
        PageBaseAdmin.PUBLICATION_FIELDS,
        PageBaseAdmin.NAVIGATION_FIELDS,
        PageBaseAdmin.SEO_FIELDS,
    )


admin.site.register(Category, CategoryAdmin)


class ArticleAdmin(PageBaseAdmin):
    
    """Admin settings for the Article model."""
    
    date_hierarchy = "date"
    
    search_fields = PageBaseAdmin.search_fields + ("content", "summary",)
    
    list_display = ("title", "date", "is_online", "get_date_modified",)
    
    list_filter = ("is_online", "categories",)
    
    fieldsets = (
        (None, {
            "fields": ("title", "url_title", "news_feed", "date",),
        }),
        ("Content", {
            "fields": ("image", "content", "summary",),
        }),
        ("Publication", {
            "fields": ("categories", "authors", "is_online",),
            "classes": ("collapse",),
        }),
        PageBaseAdmin.NAVIGATION_FIELDS,
        PageBaseAdmin.SEO_FIELDS,
    )
    
    raw_id_fields = ("image",)
    
    filter_horizontal = ("categories", "authors",)
    
    def save_related(self, request, form, formsets, change):
        """Saves the author of the article."""
        super(ArticleAdmin, self).save_related(request, form, formsets, change)
        # For new articles, add in the current author.
        if not change and not form.cleaned_data["authors"]:
            form.instance.authors.add(request.user)
    
    
admin.site.register(Article, ArticleAdmin)


# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'NewsFeed'
        db.create_table('news_newsfeed', (
            ('page', self.gf('django.db.models.fields.related.OneToOneField')(related_name='+', unique=True, primary_key=True, to=orm['pages.Page'])),
            ('content_primary', self.gf('cms.models.fields.HtmlField')(blank=True)),
            ('per_page', self.gf('django.db.models.fields.IntegerField')(default=5, null=True, blank=True)),
        ))
        db.send_create_signal('news', ['NewsFeed'])

        # Adding model 'Category'
        db.create_table('news_category', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('is_online', self.gf('django.db.models.fields.BooleanField')(default=True)),
            ('browser_title', self.gf('django.db.models.fields.CharField')(max_length=1000, blank=True)),
            ('meta_keywords', self.gf('django.db.models.fields.CharField')(max_length=1000, blank=True)),
            ('meta_description', self.gf('django.db.models.fields.TextField')(blank=True)),
            ('sitemap_priority', self.gf('django.db.models.fields.FloatField')(default=None, null=True, blank=True)),
            ('sitemap_changefreq', self.gf('django.db.models.fields.IntegerField')(default=None, null=True, blank=True)),
            ('robots_index', self.gf('django.db.models.fields.BooleanField')(default=True)),
            ('robots_follow', self.gf('django.db.models.fields.BooleanField')(default=True)),
            ('robots_archive', self.gf('django.db.models.fields.BooleanField')(default=True)),
            ('url_title', self.gf('django.db.models.fields.SlugField')(max_length=50)),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=1000)),
            ('short_title', self.gf('django.db.models.fields.CharField')(max_length=200, blank=True)),
            ('content_primary', self.gf('cms.models.fields.HtmlField')(blank=True)),
        ))
        db.send_create_signal('news', ['Category'])

        # Adding unique constraint on 'Category', fields ['url_title']
        db.create_unique('news_category', ['url_title'])

        # Adding model 'Article'
        db.create_table('news_article', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('is_online', self.gf('django.db.models.fields.BooleanField')(default=True)),
            ('browser_title', self.gf('django.db.models.fields.CharField')(max_length=1000, blank=True)),
            ('meta_keywords', self.gf('django.db.models.fields.CharField')(max_length=1000, blank=True)),
            ('meta_description', self.gf('django.db.models.fields.TextField')(blank=True)),
            ('sitemap_priority', self.gf('django.db.models.fields.FloatField')(default=None, null=True, blank=True)),
            ('sitemap_changefreq', self.gf('django.db.models.fields.IntegerField')(default=None, null=True, blank=True)),
            ('robots_index', self.gf('django.db.models.fields.BooleanField')(default=True)),
            ('robots_follow', self.gf('django.db.models.fields.BooleanField')(default=True)),
            ('robots_archive', self.gf('django.db.models.fields.BooleanField')(default=True)),
            ('url_title', self.gf('django.db.models.fields.SlugField')(max_length=50)),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=1000)),
            ('short_title', self.gf('django.db.models.fields.CharField')(max_length=200, blank=True)),
            ('news_feed', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['news.NewsFeed'])),
            ('date', self.gf('django.db.models.fields.DateField')(default=datetime.datetime.now, db_index=True)),
            ('image', self.gf('cms.apps.media.models.ImageRefField')(blank=True, related_name='+', null=True, on_delete=models.PROTECT, to=orm['media.File'])),
            ('content', self.gf('cms.models.fields.HtmlField')(blank=True)),
            ('summary', self.gf('cms.models.fields.HtmlField')(blank=True)),
        ))
        db.send_create_signal('news', ['Article'])

        # Adding unique constraint on 'Article', fields ['news_feed', 'date', 'url_title']
        db.create_unique('news_article', ['news_feed_id', 'date', 'url_title'])

        # Adding M2M table for field categories on 'Article'
        db.create_table('news_article_categories', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('article', models.ForeignKey(orm['news.article'], null=False)),
            ('category', models.ForeignKey(orm['news.category'], null=False))
        ))
        db.create_unique('news_article_categories', ['article_id', 'category_id'])

        # Adding M2M table for field authors on 'Article'
        db.create_table('news_article_authors', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('article', models.ForeignKey(orm['news.article'], null=False)),
            ('user', models.ForeignKey(orm['auth.user'], null=False))
        ))
        db.create_unique('news_article_authors', ['article_id', 'user_id'])

    def backwards(self, orm):
        # Removing unique constraint on 'Article', fields ['news_feed', 'date', 'url_title']
        db.delete_unique('news_article', ['news_feed_id', 'date', 'url_title'])

        # Removing unique constraint on 'Category', fields ['url_title']
        db.delete_unique('news_category', ['url_title'])

        # Deleting model 'NewsFeed'
        db.delete_table('news_newsfeed')

        # Deleting model 'Category'
        db.delete_table('news_category')

        # Deleting model 'Article'
        db.delete_table('news_article')

        # Removing M2M table for field categories on 'Article'
        db.delete_table('news_article_categories')

        # Removing M2M table for field authors on 'Article'
        db.delete_table('news_article_authors')

    models = {
        'auth.group': {
            'Meta': {'object_name': 'Group'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '80'}),
            'permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'})
        },
        'auth.permission': {
            'Meta': {'ordering': "('content_type__app_label', 'content_type__model', 'codename')", 'unique_together': "(('content_type', 'codename'),)", 'object_name': 'Permission'},
            'codename': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        },
        'auth.user': {
            'Meta': {'object_name': 'User'},
            'date_joined': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}),
            'first_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'groups': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Group']", 'symmetrical': 'False', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'is_staff': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'is_superuser': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'last_login': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'last_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'password': ('django.db.models.fields.CharField', [], {'max_length': '128'}),
            'user_permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'}),
            'username': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '30'})
        },
        'contenttypes.contenttype': {
            'Meta': {'ordering': "('name',)", 'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'media.file': {
            'Meta': {'ordering': "('title',)", 'object_name': 'File'},
            'file': ('django.db.models.fields.files.FileField', [], {'max_length': '250'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'labels': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['media.Label']", 'symmetrical': 'False', 'blank': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '200'})
        },
        'media.label': {
            'Meta': {'ordering': "('name',)", 'object_name': 'Label'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '200'})
        },
        'news.article': {
            'Meta': {'ordering': "('-date',)", 'unique_together': "(('news_feed', 'date', 'url_title'),)", 'object_name': 'Article'},
            'authors': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.User']", 'symmetrical': 'False', 'blank': 'True'}),
            'browser_title': ('django.db.models.fields.CharField', [], {'max_length': '1000', 'blank': 'True'}),
            'categories': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['news.Category']", 'symmetrical': 'False', 'blank': 'True'}),
            'content': ('cms.models.fields.HtmlField', [], {'blank': 'True'}),
            'date': ('django.db.models.fields.DateField', [], {'default': 'datetime.datetime.now', 'db_index': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('cms.apps.media.models.ImageRefField', [], {'blank': 'True', 'related_name': "'+'", 'null': 'True', 'on_delete': 'models.PROTECT', 'to': "orm['media.File']"}),
            'is_online': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'meta_description': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'meta_keywords': ('django.db.models.fields.CharField', [], {'max_length': '1000', 'blank': 'True'}),
            'news_feed': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['news.NewsFeed']"}),
            'robots_archive': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'robots_follow': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'robots_index': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'short_title': ('django.db.models.fields.CharField', [], {'max_length': '200', 'blank': 'True'}),
            'sitemap_changefreq': ('django.db.models.fields.IntegerField', [], {'default': 'None', 'null': 'True', 'blank': 'True'}),
            'sitemap_priority': ('django.db.models.fields.FloatField', [], {'default': 'None', 'null': 'True', 'blank': 'True'}),
            'summary': ('cms.models.fields.HtmlField', [], {'blank': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '1000'}),
            'url_title': ('django.db.models.fields.SlugField', [], {'max_length': '50'})
        },
        'news.category': {
            'Meta': {'ordering': "('title',)", 'unique_together': "(('url_title',),)", 'object_name': 'Category'},
            'browser_title': ('django.db.models.fields.CharField', [], {'max_length': '1000', 'blank': 'True'}),
            'content_primary': ('cms.models.fields.HtmlField', [], {'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_online': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'meta_description': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'meta_keywords': ('django.db.models.fields.CharField', [], {'max_length': '1000', 'blank': 'True'}),
            'robots_archive': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'robots_follow': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'robots_index': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'short_title': ('django.db.models.fields.CharField', [], {'max_length': '200', 'blank': 'True'}),
            'sitemap_changefreq': ('django.db.models.fields.IntegerField', [], {'default': 'None', 'null': 'True', 'blank': 'True'}),
            'sitemap_priority': ('django.db.models.fields.FloatField', [], {'default': 'None', 'null': 'True', 'blank': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '1000'}),
            'url_title': ('django.db.models.fields.SlugField', [], {'max_length': '50'})
        },
        'news.newsfeed': {
            'Meta': {'object_name': 'NewsFeed'},
            'content_primary': ('cms.models.fields.HtmlField', [], {'blank': 'True'}),
            'page': ('django.db.models.fields.related.OneToOneField', [], {'related_name': "'+'", 'unique': 'True', 'primary_key': 'True', 'to': "orm['pages.Page']"}),
            'per_page': ('django.db.models.fields.IntegerField', [], {'default': '5', 'null': 'True', 'blank': 'True'})
        },
        'pages.page': {
            'Meta': {'ordering': "('left',)", 'unique_together': "(('parent', 'url_title'),)", 'object_name': 'Page'},
            'browser_title': ('django.db.models.fields.CharField', [], {'max_length': '1000', 'blank': 'True'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'expiry_date': ('django.db.models.fields.DateTimeField', [], {'db_index': 'True', 'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'in_navigation': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'is_online': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'left': ('django.db.models.fields.IntegerField', [], {'db_index': 'True'}),
            'meta_description': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'meta_keywords': ('django.db.models.fields.CharField', [], {'max_length': '1000', 'blank': 'True'}),
            'parent': ('django.db.models.fields.related.ForeignKey', [], {'blank': 'True', 'related_name': "'child_set'", 'null': 'True', 'to': "orm['pages.Page']"}),
            'publication_date': ('django.db.models.fields.DateTimeField', [], {'db_index': 'True', 'null': 'True', 'blank': 'True'}),
            'right': ('django.db.models.fields.IntegerField', [], {'db_index': 'True'}),
            'robots_archive': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'robots_follow': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'robots_index': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'short_title': ('django.db.models.fields.CharField', [], {'max_length': '200', 'blank': 'True'}),
            'sitemap_changefreq': ('django.db.models.fields.IntegerField', [], {'default': 'None', 'null': 'True', 'blank': 'True'}),
            'sitemap_priority': ('django.db.models.fields.FloatField', [], {'default': 'None', 'null': 'True', 'blank': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '1000'}),
            'url_title': ('django.db.models.fields.SlugField', [], {'max_length': '50'})
        }
    }

    complete_apps = ['news']


"""Models used by {{ project_name }} project."""

from cms.models import HtmlField
from cms.apps.pages.models import ContentBase


class Content(ContentBase):
    
    content_primary = HtmlField(
        "primary content",
        blank = True
    )


# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'Link'
        db.create_table('links_link', (
            ('page', self.gf('django.db.models.fields.related.OneToOneField')(related_name='+', unique=True, primary_key=True, to=orm['pages.Page'])),
            ('link_url', self.gf('cms.models.fields.LinkField')(max_length=1000)),
        ))
        db.send_create_signal('links', ['Link'])

    def backwards(self, orm):
        # Deleting model 'Link'
        db.delete_table('links_link')

    models = {
        'contenttypes.contenttype': {
            'Meta': {'ordering': "('name',)", 'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'links.link': {
            'Meta': {'object_name': 'Link'},
            'link_url': ('cms.models.fields.LinkField', [], {'max_length': '1000'}),
            'page': ('django.db.models.fields.related.OneToOneField', [], {'related_name': "'+'", 'unique': 'True', 'primary_key': 'True', 'to': "orm['pages.Page']"})
        },
        'pages.page': {
            'Meta': {'ordering': "('left',)", 'unique_together': "(('parent', 'url_title'),)", 'object_name': 'Page'},
            'browser_title': ('django.db.models.fields.CharField', [], {'max_length': '1000', 'blank': 'True'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'expiry_date': ('django.db.models.fields.DateTimeField', [], {'db_index': 'True', 'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'in_navigation': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'is_online': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'left': ('django.db.models.fields.IntegerField', [], {'db_index': 'True'}),
            'meta_description': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'meta_keywords': ('django.db.models.fields.CharField', [], {'max_length': '1000', 'blank': 'True'}),
            'parent': ('django.db.models.fields.related.ForeignKey', [], {'blank': 'True', 'related_name': "'child_set'", 'null': 'True', 'to': "orm['pages.Page']"}),
            'publication_date': ('django.db.models.fields.DateTimeField', [], {'db_index': 'True', 'null': 'True', 'blank': 'True'}),
            'right': ('django.db.models.fields.IntegerField', [], {'db_index': 'True'}),
            'robots_archive': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'robots_follow': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'robots_index': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'short_title': ('django.db.models.fields.CharField', [], {'max_length': '200', 'blank': 'True'}),
            'sitemap_changefreq': ('django.db.models.fields.IntegerField', [], {'default': 'None', 'null': 'True', 'blank': 'True'}),
            'sitemap_priority': ('django.db.models.fields.FloatField', [], {'default': 'None', 'null': 'True', 'blank': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '1000'}),
            'url_title': ('django.db.models.fields.SlugField', [], {'max_length': '50'})
        }
    }

    complete_apps = ['links']